# This file was auto-generated by Fern from our API Definition.

from ..core.client_wrapper import SyncClientWrapper
from .batch.client import BatchClient
from ..core.client_wrapper import AsyncClientWrapper
from .batch.client import AsyncBatchClient


class ExpressionMeasurementClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._client_wrapper = client_wrapper
        self.batch = BatchClient(client_wrapper=self._client_wrapper)


class AsyncExpressionMeasurementClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._client_wrapper = client_wrapper
        self.batch = AsyncBatchClient(client_wrapper=self._client_wrapper)
