# This file was auto-generated by Fern from our API Definition.

from ....core.pydantic_utilities import UniversalBaseModel
import pydantic
import typing
from .language_prediction import LanguagePrediction
from ....core.pydantic_utilities import IS_PYDANTIC_V2


class GroupedPredictionsLanguagePrediction(UniversalBaseModel):
    id: str = pydantic.Field()
    """
    An automatically generated label to identify individuals in your media file. Will be `unknown` if you have chosen to disable identification, or if the model is unable to distinguish between individuals.
    """

    predictions: typing.List[LanguagePrediction]

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
