# This file was auto-generated by Fern from our API Definition.

import typing

ReturnCustomVoiceBaseVoice = typing.Union[
    typing.Literal["ITO", "KORA", "DACHER", "AURA", "FINN", "WHIMSY", "STELLA", "SUNNY"], typing.Any
]
