# This file was auto-generated by Fern from our API Definition.

import typing

ReturnChatEventType = typing.Union[
    typing.Literal[
        "SYSTEM_PROMPT", "USER_MESSAGE", "USER_INTERRUPTION", "AGENT_MESSAGE", "FUNCTION_CALL", "FUNCTION_CALL_RESPONSE"
    ],
    typing.Any,
]
