# This file was auto-generated by Fern from our API Definition.

from ....core.pydantic_utilities import UniversalBaseModel
from .source import Source
import typing
from .tl_inference_results import TlInferenceResults
import pydantic
from ....core.pydantic_utilities import IS_PYDANTIC_V2


class TlInferenceSourcePredictResult(UniversalBaseModel):
    source: Source
    results: typing.Optional[TlInferenceResults] = None
    error: typing.Optional[str] = pydantic.Field(default=None)
    """
    An error message.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
